@@ -9,6 +9,7 @@ from selenium.webdriver import ActionChains
 from selenium.webdriver.remote.switch_to import SwitchTo
 from selenium.webdriver.support.wait import WebDriverWait
 from selenium.webdriver.remote.webelement import WebElement
+from selenium.webdriver.support import expected_conditions as EC
 from melon.webdrivers import driver
 from melon.settings import get_config
 
@@ -20,10 +21,12 @@ class MelonElement(WebElement):
         super(MelonElement, self).__init__(None, None)
         self.label = label
         self.timeout = timeout
+        self.by = by
+        self.loc = loc
         self.locator = (by, loc)
 
     def __repr__(self):
-        return '{"label": "", "locator": ["%s", "%s"]}' % (self.label, *self.locator)
+        return '{"label": "%s", "locator": ["%s", "%s"]}' % (self.label, self.by, self.loc)
 
 
 class MelonElements(WebElement, List):
@@ -33,10 +36,12 @@ class MelonElements(WebElement, List):
         super(MelonElements, self).__init__(None, None)
         self.label = label
         self.timeout = timeout
+        self.by = by
+        self.loc = loc
         self.locator = (by, loc)
 
     def __repr__(self):
-        return '{"label": "", "locator": ["%s", "%s"]}' % (self.label, *self.locator)
+        return '{"label": "%s", "locator": ["%s", "%s"]}' % (self.label, self.by, self.loc)
 
 
 class BasePage:
@@ -59,6 +64,18 @@ class BasePage:
         self.__proxy_allure(elements)
         return elements
 
+    def find_element_await(self, locator: Tuple, timout: float) -> WebElement:
+        """定位单个元素并等待"""
+        element = self.webdriver_wait(timout).until(EC.presence_of_element_located(locator))
+        self.__proxy_allure(element)
+        return element
+
+    def find_elements_await(self, locator: Tuple, timout: float) -> List[WebElement]:
+        """定位多个元素并等待"""
+        elements = self.webdriver_wait(timout).until(EC.presence_of_all_elements_located(locator))
+        self.__proxy_allure(elements)
+        return elements
+
     def switch_to(self) -> SwitchTo:
         """切换"""
         return self.driver.switch_to
@@ -84,13 +101,14 @@ class BasePage:
         base_url = get_config('melon.selenium.url')
 
         if url.startswith('http://') or url.startswith('https://'):
-            self.driver.get(url)
+            self.__step(f'跳转到 {url}', self.driver.get(url))
             return
         if not url.startswith('/'):
             url = '/' + url
         if base_url.endswith('/'):
             base_url = base_url[:-1]
-        self.driver.get(f'{base_url}{url}')
+        url = f'{base_url}{url}'
+        self.__step(f'跳转到 {url}', self.driver.get(url))
 
     def close(self):
         """关闭浏览器"""
@@ -127,7 +145,11 @@ class BasePage:
         """
         代理单属性
         """
-        _proxy = self.find_element(_target.locator)
+        timeout = _target.timeout
+        if timeout:
+            _proxy = self.find_element_await(_target.locator, timeout)
+        else:
+            _proxy = self.find_element(_target.locator)
         _proxy._label = _target.label
         return _proxy
 
@@ -135,7 +157,11 @@ class BasePage:
         """
         代理可迭代属性
         """
-        _proxy = self.find_elements(_target.locator)
+        timeout = _target.timeout
+        if timeout:
+            _proxy = self.find_elements_await(_target.locator, timeout)
+        else:
+            _proxy = self.find_elements(_target.locator)
         [setattr(e, '_label', _target.label) for e in _proxy if e]
         return _proxy
 
