@@ -6,12 +6,16 @@ from selenium import webdriver
 from melon.settings import get_config
 
 
-_DRIVER_ROUTER = dict(CHROME=webdriver.Chrome, FIREFOX=webdriver.Firefox, IE=webdriver.Ie, EDGE=webdriver.Edge)
+_DRIVER_ROUTER = dict(
+    CHROME=webdriver.Chrome,
+    FIREFOX=webdriver.Firefox,
+    IE=webdriver.Ie,
+    EDGE=webdriver.Edge
+)
 
 
 def create_driver():
-    """构建单例 web driver"""
-
+    """构建单例 webdriver"""
     url = get_config('melon.selenium.url')
     assert url and url != '', 'URL must not be blank'
 
